"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .openroutererror import OpenRouterError
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .badgatewayresponse_error import (
        BadGatewayResponseError,
        BadGatewayResponseErrorData,
    )
    from .badrequestresponse_error import (
        BadRequestResponseError,
        BadRequestResponseErrorData,
    )
    from .chaterror import ChatError, ChatErrorData
    from .edgenetworktimeoutresponse_error import (
        EdgeNetworkTimeoutResponseError,
        EdgeNetworkTimeoutResponseErrorData,
    )
    from .forbiddenresponse_error import (
        ForbiddenResponseError,
        ForbiddenResponseErrorData,
    )
    from .internalserverresponse_error import (
        InternalServerResponseError,
        InternalServerResponseErrorData,
    )
    from .no_response_error import NoResponseError
    from .notfoundresponse_error import NotFoundResponseError, NotFoundResponseErrorData
    from .openrouterdefaulterror import OpenRouterDefaultError
    from .payloadtoolargeresponse_error import (
        PayloadTooLargeResponseError,
        PayloadTooLargeResponseErrorData,
    )
    from .paymentrequiredresponse_error import (
        PaymentRequiredResponseError,
        PaymentRequiredResponseErrorData,
    )
    from .provideroverloadedresponse_error import (
        ProviderOverloadedResponseError,
        ProviderOverloadedResponseErrorData,
    )
    from .requesttimeoutresponse_error import (
        RequestTimeoutResponseError,
        RequestTimeoutResponseErrorData,
    )
    from .responsevalidationerror import ResponseValidationError
    from .serviceunavailableresponse_error import (
        ServiceUnavailableResponseError,
        ServiceUnavailableResponseErrorData,
    )
    from .toomanyrequestsresponse_error import (
        TooManyRequestsResponseError,
        TooManyRequestsResponseErrorData,
    )
    from .unauthorizedresponse_error import (
        UnauthorizedResponseError,
        UnauthorizedResponseErrorData,
    )
    from .unprocessableentityresponse_error import (
        UnprocessableEntityResponseError,
        UnprocessableEntityResponseErrorData,
    )

__all__ = [
    "BadGatewayResponseError",
    "BadGatewayResponseErrorData",
    "BadRequestResponseError",
    "BadRequestResponseErrorData",
    "ChatError",
    "ChatErrorData",
    "EdgeNetworkTimeoutResponseError",
    "EdgeNetworkTimeoutResponseErrorData",
    "ForbiddenResponseError",
    "ForbiddenResponseErrorData",
    "InternalServerResponseError",
    "InternalServerResponseErrorData",
    "NoResponseError",
    "NotFoundResponseError",
    "NotFoundResponseErrorData",
    "OpenRouterDefaultError",
    "OpenRouterError",
    "PayloadTooLargeResponseError",
    "PayloadTooLargeResponseErrorData",
    "PaymentRequiredResponseError",
    "PaymentRequiredResponseErrorData",
    "ProviderOverloadedResponseError",
    "ProviderOverloadedResponseErrorData",
    "RequestTimeoutResponseError",
    "RequestTimeoutResponseErrorData",
    "ResponseValidationError",
    "ServiceUnavailableResponseError",
    "ServiceUnavailableResponseErrorData",
    "TooManyRequestsResponseError",
    "TooManyRequestsResponseErrorData",
    "UnauthorizedResponseError",
    "UnauthorizedResponseErrorData",
    "UnprocessableEntityResponseError",
    "UnprocessableEntityResponseErrorData",
]

_dynamic_imports: dict[str, str] = {
    "BadGatewayResponseError": ".badgatewayresponse_error",
    "BadGatewayResponseErrorData": ".badgatewayresponse_error",
    "BadRequestResponseError": ".badrequestresponse_error",
    "BadRequestResponseErrorData": ".badrequestresponse_error",
    "ChatError": ".chaterror",
    "ChatErrorData": ".chaterror",
    "EdgeNetworkTimeoutResponseError": ".edgenetworktimeoutresponse_error",
    "EdgeNetworkTimeoutResponseErrorData": ".edgenetworktimeoutresponse_error",
    "ForbiddenResponseError": ".forbiddenresponse_error",
    "ForbiddenResponseErrorData": ".forbiddenresponse_error",
    "InternalServerResponseError": ".internalserverresponse_error",
    "InternalServerResponseErrorData": ".internalserverresponse_error",
    "NoResponseError": ".no_response_error",
    "NotFoundResponseError": ".notfoundresponse_error",
    "NotFoundResponseErrorData": ".notfoundresponse_error",
    "OpenRouterDefaultError": ".openrouterdefaulterror",
    "PayloadTooLargeResponseError": ".payloadtoolargeresponse_error",
    "PayloadTooLargeResponseErrorData": ".payloadtoolargeresponse_error",
    "PaymentRequiredResponseError": ".paymentrequiredresponse_error",
    "PaymentRequiredResponseErrorData": ".paymentrequiredresponse_error",
    "ProviderOverloadedResponseError": ".provideroverloadedresponse_error",
    "ProviderOverloadedResponseErrorData": ".provideroverloadedresponse_error",
    "RequestTimeoutResponseError": ".requesttimeoutresponse_error",
    "RequestTimeoutResponseErrorData": ".requesttimeoutresponse_error",
    "ResponseValidationError": ".responsevalidationerror",
    "ServiceUnavailableResponseError": ".serviceunavailableresponse_error",
    "ServiceUnavailableResponseErrorData": ".serviceunavailableresponse_error",
    "TooManyRequestsResponseError": ".toomanyrequestsresponse_error",
    "TooManyRequestsResponseErrorData": ".toomanyrequestsresponse_error",
    "UnauthorizedResponseError": ".unauthorizedresponse_error",
    "UnauthorizedResponseErrorData": ".unauthorizedresponse_error",
    "UnprocessableEntityResponseError": ".unprocessableentityresponse_error",
    "UnprocessableEntityResponseErrorData": ".unprocessableentityresponse_error",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, SecurityMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SecurityTypedDict(TypedDict):
    api_key: NotRequired[str]


class Security(BaseModel):
    api_key: Annotated[
        Optional[str],
        FieldMetadata(
            security=SecurityMetadata(
                scheme=True,
                scheme_type="http",
                sub_type="bearer",
                field_name="Authorization",
            )
        ),
    ] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel, UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypedDict


CodeEnum = Union[
    Literal[
        "server_error",
        "rate_limit_exceeded",
        "invalid_prompt",
        "vector_store_timeout",
        "invalid_image",
        "invalid_image_format",
        "invalid_base64_image",
        "invalid_image_url",
        "image_too_large",
        "image_too_small",
        "image_parse_error",
        "image_content_policy_violation",
        "invalid_image_mode",
        "image_file_too_large",
        "unsupported_image_media_type",
        "empty_image_file",
        "failed_to_download_image",
        "image_file_not_found",
    ],
    UnrecognizedStr,
]


class ResponsesErrorFieldTypedDict(TypedDict):
    r"""Error information returned from the API"""

    code: CodeEnum
    message: str


class ResponsesErrorField(BaseModel):
    r"""Error information returned from the API"""

    code: Annotated[CodeEnum, PlainValidator(validate_open_enum(False))]

    message: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


InstructType = Union[
    Literal[
        "none",
        "airoboros",
        "alpaca",
        "alpaca-modif",
        "chatml",
        "claude",
        "code-llama",
        "gemma",
        "llama2",
        "llama3",
        "mistral",
        "nemotron",
        "neural",
        "openchat",
        "phi3",
        "rwkv",
        "vicuna",
        "zephyr",
        "deepseek-r1",
        "deepseek-v3.1",
        "qwq",
        "qwen3",
    ],
    UnrecognizedStr,
]
r"""Instruction format type"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


Quantization = Union[
    Literal[
        "int4",
        "int8",
        "fp4",
        "fp6",
        "fp8",
        "fp16",
        "bf16",
        "fp32",
        "unknown",
    ],
    UnrecognizedStr,
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class ModelsCountResponseDataTypedDict(TypedDict):
    r"""Model count data"""

    count: float
    r"""Total number of available models"""


class ModelsCountResponseData(BaseModel):
    r"""Model count data"""

    count: float
    r"""Total number of available models"""


class ModelsCountResponseTypedDict(TypedDict):
    r"""Model count data"""

    data: ModelsCountResponseDataTypedDict
    r"""Model count data"""


class ModelsCountResponse(BaseModel):
    r"""Model count data"""

    data: ModelsCountResponseData
    r"""Model count data"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .openresponsestoplogprobs import (
    OpenResponsesTopLogprobs,
    OpenResponsesTopLogprobsTypedDict,
)
from openrouter.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OpenResponsesLogProbsTypedDict(TypedDict):
    r"""Log probability information for a token"""

    logprob: float
    token: str
    top_logprobs: NotRequired[List[OpenResponsesTopLogprobsTypedDict]]


class OpenResponsesLogProbs(BaseModel):
    r"""Log probability information for a token"""

    logprob: float

    token: str

    top_logprobs: Optional[List[OpenResponsesTopLogprobs]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.components import (
    listendpointsresponse as components_listendpointsresponse,
)
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ListEndpointsRequestTypedDict(TypedDict):
    author: str
    slug: str


class ListEndpointsRequest(BaseModel):
    author: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    slug: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class ListEndpointsResponseTypedDict(TypedDict):
    r"""Returns a list of endpoints"""

    data: components_listendpointsresponse.ListEndpointsResponseTypedDict
    r"""List of available endpoints for a model"""


class ListEndpointsResponse(BaseModel):
    r"""Returns a list of endpoints"""

    data: components_listendpointsresponse.ListEndpointsResponse
    r"""List of available endpoints for a model"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, SecurityMetadata
from typing_extensions import Annotated, TypedDict


class CreateCoinbaseChargeSecurityTypedDict(TypedDict):
    bearer: str


class CreateCoinbaseChargeSecurity(BaseModel):
    bearer: Annotated[
        str,
        FieldMetadata(
            security=SecurityMetadata(
                scheme=True,
                scheme_type="http",
                sub_type="bearer",
                field_name="Authorization",
            )
        ),
    ]


class CallDataTypedDict(TypedDict):
    deadline: str
    fee_amount: str
    id: str
    operator: str
    prefix: str
    recipient: str
    recipient_amount: str
    recipient_currency: str
    refund_destination: str
    signature: str


class CallData(BaseModel):
    deadline: str

    fee_amount: str

    id: str

    operator: str

    prefix: str

    recipient: str

    recipient_amount: str

    recipient_currency: str

    refund_destination: str

    signature: str


class MetadataTypedDict(TypedDict):
    chain_id: float
    contract_address: str
    sender: str


class Metadata(BaseModel):
    chain_id: float

    contract_address: str

    sender: str


class TransferIntentTypedDict(TypedDict):
    call_data: CallDataTypedDict
    metadata: MetadataTypedDict


class TransferIntent(BaseModel):
    call_data: CallData

    metadata: Metadata


class Web3DataTypedDict(TypedDict):
    transfer_intent: TransferIntentTypedDict


class Web3Data(BaseModel):
    transfer_intent: TransferIntent


class CreateCoinbaseChargeDataTypedDict(TypedDict):
    id: str
    created_at: str
    expires_at: str
    web3_data: Web3DataTypedDict


class CreateCoinbaseChargeData(BaseModel):
    id: str

    created_at: str

    expires_at: str

    web3_data: Web3Data


class CreateCoinbaseChargeResponseTypedDict(TypedDict):
    r"""Returns the calldata to fulfill the transaction"""

    data: CreateCoinbaseChargeDataTypedDict


class CreateCoinbaseChargeResponse(BaseModel):
    r"""Returns the calldata to fulfill the transaction"""

    data: CreateCoinbaseChargeData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import FieldMetadata, PathParamMetadata, validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class DeleteKeysRequestTypedDict(TypedDict):
    hash: str
    r"""The hash identifier of the API key to delete"""


class DeleteKeysRequest(BaseModel):
    hash: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The hash identifier of the API key to delete"""


class DeleteKeysResponseTypedDict(TypedDict):
    r"""API key deleted successfully"""

    deleted: Literal[True]
    r"""Confirmation that the API key was deleted"""


class DeleteKeysResponse(BaseModel):
    r"""API key deleted successfully"""

    DELETED: Annotated[
        Annotated[Literal[True], AfterValidator(validate_const(True))],
        pydantic.Field(alias="deleted"),
    ] = True
    r"""Confirmation that the API key was deleted"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


DataCollection = Union[
    Literal[
        "deny",
        "allow",
    ],
    UnrecognizedStr,
]
r"""Data collection setting. If no available model provider meets the requirement, your request will return an error.
- allow: (default) allow providers which store user data non-transiently and may train on it

- deny: use only providers which do not collect user data.
"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PublicPricingTypedDict(TypedDict):
    r"""Pricing information for the model"""

    prompt: str
    r"""A value in string format that is a large number"""
    completion: str
    r"""A value in string format that is a large number"""
    request: NotRequired[str]
    r"""A value in string format that is a large number"""
    image: NotRequired[str]
    r"""A value in string format that is a large number"""
    image_token: NotRequired[str]
    r"""A value in string format that is a large number"""
    image_output: NotRequired[str]
    r"""A value in string format that is a large number"""
    audio: NotRequired[str]
    r"""A value in string format that is a large number"""
    input_audio_cache: NotRequired[str]
    r"""A value in string format that is a large number"""
    web_search: NotRequired[str]
    r"""A value in string format that is a large number"""
    internal_reasoning: NotRequired[str]
    r"""A value in string format that is a large number"""
    input_cache_read: NotRequired[str]
    r"""A value in string format that is a large number"""
    input_cache_write: NotRequired[str]
    r"""A value in string format that is a large number"""
    discount: NotRequired[float]


class PublicPricing(BaseModel):
    r"""Pricing information for the model"""

    prompt: str
    r"""A value in string format that is a large number"""

    completion: str
    r"""A value in string format that is a large number"""

    request: Optional[str] = None
    r"""A value in string format that is a large number"""

    image: Optional[str] = None
    r"""A value in string format that is a large number"""

    image_token: Optional[str] = None
    r"""A value in string format that is a large number"""

    image_output: Optional[str] = None
    r"""A value in string format that is a large number"""

    audio: Optional[str] = None
    r"""A value in string format that is a large number"""

    input_audio_cache: Optional[str] = None
    r"""A value in string format that is a large number"""

    web_search: Optional[str] = None
    r"""A value in string format that is a large number"""

    internal_reasoning: Optional[str] = None
    r"""A value in string format that is a large number"""

    input_cache_read: Optional[str] = None
    r"""A value in string format that is a large number"""

    input_cache_write: Optional[str] = None
    r"""A value in string format that is a large number"""

    discount: Optional[float] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


PDFParserEngine = Union[
    Literal[
        "mistral-ocr",
        "pdf-text",
        "native",
    ],
    UnrecognizedStr,
]
r"""The engine to use for parsing PDF files."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitem import (
    ChatMessageContentItem,
    ChatMessageContentItemTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


UserMessageContentTypedDict = TypeAliasType(
    "UserMessageContentTypedDict", Union[str, List[ChatMessageContentItemTypedDict]]
)


UserMessageContent = TypeAliasType(
    "UserMessageContent", Union[str, List[ChatMessageContentItem]]
)


class UserMessageTypedDict(TypedDict):
    content: UserMessageContentTypedDict
    role: Literal["user"]
    name: NotRequired[str]


class UserMessage(BaseModel):
    content: UserMessageContent

    ROLE: Annotated[
        Annotated[Literal["user"], AfterValidator(validate_const("user"))],
        pydantic.Field(alias="role"),
    ] = "user"

    name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .providersort import ProviderSort
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, NotRequired, TypedDict


Partition = Union[
    Literal[
        "model",
        "none",
    ],
    UnrecognizedStr,
]


class ProviderSortConfigTypedDict(TypedDict):
    by: NotRequired[Nullable[ProviderSort]]
    partition: NotRequired[Nullable[Partition]]


class ProviderSortConfig(BaseModel):
    by: Annotated[
        OptionalNullable[ProviderSort], PlainValidator(validate_open_enum(False))
    ] = UNSET

    partition: Annotated[
        OptionalNullable[Partition], PlainValidator(validate_open_enum(False))
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["by", "partition"]
        nullable_fields = ["by", "partition"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pdfparserengine import PDFParserEngine
from openrouter.types import BaseModel
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PDFParserOptionsTypedDict(TypedDict):
    r"""Options for PDF parsing."""

    engine: NotRequired[PDFParserEngine]
    r"""The engine to use for parsing PDF files."""


class PDFParserOptions(BaseModel):
    r"""Options for PDF parsing."""

    engine: Annotated[
        Optional[PDFParserEngine], PlainValidator(validate_open_enum(False))
    ] = None
    r"""The engine to use for parsing PDF files."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseinputaudio import ResponseInputAudio, ResponseInputAudioTypedDict
from .responseinputfile import ResponseInputFile, ResponseInputFileTypedDict
from .responseinputtext import ResponseInputText, ResponseInputTextTypedDict
from .responseinputvideo import ResponseInputVideo, ResponseInputVideoTypedDict
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import get_discriminator, validate_open_enum
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import PlainValidator
from typing import List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


OpenResponsesEasyInputMessageTypeMessage = Literal["message",]


OpenResponsesEasyInputMessageRoleDeveloper = Literal["developer",]


OpenResponsesEasyInputMessageRoleAssistant = Literal["assistant",]


OpenResponsesEasyInputMessageRoleSystem = Literal["system",]


OpenResponsesEasyInputMessageRoleUser = Literal["user",]


OpenResponsesEasyInputMessageRoleUnionTypedDict = TypeAliasType(
    "OpenResponsesEasyInputMessageRoleUnionTypedDict",
    Union[
        OpenResponsesEasyInputMessageRoleUser,
        OpenResponsesEasyInputMessageRoleSystem,
        OpenResponsesEasyInputMessageRoleAssistant,
        OpenResponsesEasyInputMessageRoleDeveloper,
    ],
)


OpenResponsesEasyInputMessageRoleUnion = TypeAliasType(
    "OpenResponsesEasyInputMessageRoleUnion",
    Union[
        OpenResponsesEasyInputMessageRoleUser,
        OpenResponsesEasyInputMessageRoleSystem,
        OpenResponsesEasyInputMessageRoleAssistant,
        OpenResponsesEasyInputMessageRoleDeveloper,
    ],
)


OpenResponsesEasyInputMessageContentType = Literal["input_image",]


OpenResponsesEasyInputMessageDetail = Union[
    Literal[
        "auto",
        "high",
        "low",
    ],
    UnrecognizedStr,
]


class OpenResponsesEasyInputMessageContentInputImageTypedDict(TypedDict):
    r"""Image input content item"""

    type: OpenResponsesEasyInputMessageContentType
    detail: OpenResponsesEasyInputMessageDetail
    image_url: NotRequired[Nullable[str]]


class OpenResponsesEasyInputMessageContentInputImage(BaseModel):
    r"""Image input content item"""

    type: OpenResponsesEasyInputMessageContentType

    detail: Annotated[
        OpenResponsesEasyInputMessageDetail, PlainValidator(validate_open_enum(False))
    ]

    image_url: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["image_url"]
        nullable_fields = ["image_url"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


OpenResponsesEasyInputMessageContentUnion1TypedDict = TypeAliasType(
    "OpenResponsesEasyInputMessageContentUnion1TypedDict",
    Union[
        ResponseInputTextTypedDict,
        ResponseInputAudioTypedDict,
        ResponseInputVideoTypedDict,
        OpenResponsesEasyInputMessageContentInputImageTypedDict,
        ResponseInputFileTypedDict,
    ],
)


OpenResponsesEasyInputMessageContentUnion1 = Annotated[
    Union[
        Annotated[ResponseInputText, Tag("input_text")],
        Annotated[OpenResponsesEasyInputMessageContentInputImage, Tag("input_image")],
        Annotated[ResponseInputFile, Tag("input_file")],
        Annotated[ResponseInputAudio, Tag("input_audio")],
        Annotated[ResponseInputVideo, Tag("input_video")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


OpenResponsesEasyInputMessageContentUnion2TypedDict = TypeAliasType(
    "OpenResponsesEasyInputMessageContentUnion2TypedDict",
    Union[List[OpenResponsesEasyInputMessageContentUnion1TypedDict], str],
)


OpenResponsesEasyInputMessageContentUnion2 = TypeAliasType(
    "OpenResponsesEasyInputMessageContentUnion2",
    Union[List[OpenResponsesEasyInputMessageContentUnion1], str],
)


class OpenResponsesEasyInputMessageTypedDict(TypedDict):
    role: OpenResponsesEasyInputMessageRoleUnionTypedDict
    content: OpenResponsesEasyInputMessageContentUnion2TypedDict
    type: NotRequired[OpenResponsesEasyInputMessageTypeMessage]


class OpenResponsesEasyInputMessage(BaseModel):
    role: OpenResponsesEasyInputMessageRoleUnion

    content: OpenResponsesEasyInputMessageContentUnion2

    type: Optional[OpenResponsesEasyInputMessageTypeMessage] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal, Union
from typing_extensions import Annotated, TypeAliasType


Schema0Enum = Union[
    Literal[
        "AI21",
        "AionLabs",
        "Alibaba",
        "Amazon Bedrock",
        "Amazon Nova",
        "Anthropic",
        "Arcee AI",
        "AtlasCloud",
        "Avian",
        "Azure",
        "BaseTen",
        "BytePlus",
        "Black Forest Labs",
        "Cerebras",
        "Chutes",
        "Cirrascale",
        "Clarifai",
        "Cloudflare",
        "Cohere",
        "Crusoe",
        "DeepInfra",
        "DeepSeek",
        "Featherless",
        "Fireworks",
        "Friendli",
        "GMICloud",
        "Google",
        "Google AI Studio",
        "Groq",
        "Hyperbolic",
        "Inception",
        "Inceptron",
        "InferenceNet",
        "Infermatic",
        "Inflection",
        "Liquid",
        "Mara",
        "Mancer 2",
        "Minimax",
        "ModelRun",
        "Mistral",
        "Modular",
        "Moonshot AI",
        "Morph",
        "NCompass",
        "Nebius",
        "NextBit",
        "Novita",
        "Nvidia",
        "OpenAI",
        "OpenInference",
        "Parasail",
        "Perplexity",
        "Phala",
        "Relace",
        "SambaNova",
        "Seed",
        "SiliconFlow",
        "Sourceful",
        "Stealth",
        "StreamLake",
        "Switchpoint",
        "Together",
        "Upstage",
        "Venice",
        "WandB",
        "Xiaomi",
        "xAI",
        "Z.AI",
        "FakeProvider",
    ],
    UnrecognizedStr,
]


Schema0TypedDict = TypeAliasType("Schema0TypedDict", Union[Schema0Enum, str])


Schema0 = TypeAliasType(
    "Schema0",
    Union[Annotated[Schema0Enum, PlainValidator(validate_open_enum(False))], str],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


OpenResponsesImageGenCallPartialImageType = Literal[
    "response.image_generation_call.partial_image",
]


class OpenResponsesImageGenCallPartialImageTypedDict(TypedDict):
    r"""Image generation call with partial image"""

    type: OpenResponsesImageGenCallPartialImageType
    item_id: str
    output_index: float
    sequence_number: float
    partial_image_b64: str
    partial_image_index: float


class OpenResponsesImageGenCallPartialImage(BaseModel):
    r"""Image generation call with partial image"""

    type: OpenResponsesImageGenCallPartialImageType

    item_id: str

    output_index: float

    sequence_number: float

    partial_image_b64: str

    partial_image_index: float



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChatStreamingMessageToolCallFunctionTypedDict(TypedDict):
    name: NotRequired[str]
    arguments: NotRequired[str]


class ChatStreamingMessageToolCallFunction(BaseModel):
    name: Optional[str] = None

    arguments: Optional[str] = None


class ChatStreamingMessageToolCallTypedDict(TypedDict):
    index: float
    id: NotRequired[str]
    type: Literal["function"]
    function: NotRequired[ChatStreamingMessageToolCallFunctionTypedDict]


class ChatStreamingMessageToolCall(BaseModel):
    index: float

    id: Optional[str] = None

    TYPE: Annotated[
        Annotated[
            Optional[Literal["function"]], AfterValidator(validate_const("function"))
        ],
        pydantic.Field(alias="type"),
    ] = "function"

    function: Optional[ChatStreamingMessageToolCallFunction] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from openrouter.utils import validate_open_enum
from pydantic import model_serializer
from pydantic.functional_validators import PlainValidator
from typing import Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


CreateAuthKeysCodeCodeChallengeMethod = Union[
    Literal[
        "S256",
        "plain",
    ],
    UnrecognizedStr,
]
r"""The method used to generate the code challenge"""


class CreateAuthKeysCodeRequestTypedDict(TypedDict):
    callback_url: str
    r"""The callback URL to redirect to after authorization. Note, only https URLs on ports 443 and 3000 are allowed."""
    code_challenge: NotRequired[str]
    r"""PKCE code challenge for enhanced security"""
    code_challenge_method: NotRequired[CreateAuthKeysCodeCodeChallengeMethod]
    r"""The method used to generate the code challenge"""
    limit: NotRequired[float]
    r"""Credit limit for the API key to be created"""
    expires_at: NotRequired[Nullable[datetime]]
    r"""Optional expiration time for the API key to be created"""


class CreateAuthKeysCodeRequest(BaseModel):
    callback_url: str
    r"""The callback URL to redirect to after authorization. Note, only https URLs on ports 443 and 3000 are allowed."""

    code_challenge: Optional[str] = None
    r"""PKCE code challenge for enhanced security"""

    code_challenge_method: Annotated[
        Optional[CreateAuthKeysCodeCodeChallengeMethod],
        PlainValidator(validate_open_enum(False)),
    ] = None
    r"""The method used to generate the code challenge"""

    limit: Optional[float] = None
    r"""Credit limit for the API key to be created"""

    expires_at: OptionalNullable[datetime] = UNSET
    r"""Optional expiration time for the API key to be created"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "code_challenge",
            "code_challenge_method",
            "limit",
            "expires_at",
        ]
        nullable_fields = ["expires_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CreateAuthKeysCodeDataTypedDict(TypedDict):
    r"""Auth code data"""

    id: str
    r"""The authorization code ID to use in the exchange request"""
    app_id: float
    r"""The application ID associated with this auth code"""
    created_at: str
    r"""ISO 8601 timestamp of when the auth code was created"""


class CreateAuthKeysCodeData(BaseModel):
    r"""Auth code data"""

    id: str
    r"""The authorization code ID to use in the exchange request"""

    app_id: float
    r"""The application ID associated with this auth code"""

    created_at: str
    r"""ISO 8601 timestamp of when the auth code was created"""


class CreateAuthKeysCodeResponseTypedDict(TypedDict):
    r"""Successfully created authorization code"""

    data: CreateAuthKeysCodeDataTypedDict
    r"""Auth code data"""


class CreateAuthKeysCodeResponse(BaseModel):
    r"""Successfully created authorization code"""

    data: CreateAuthKeysCodeData
    r"""Auth code data"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chatmessagecontentitemcachecontrol import (
    ChatMessageContentItemCacheControl,
    ChatMessageContentItemCacheControlTypedDict,
)
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChatMessageContentItemTextTypedDict(TypedDict):
    text: str
    type: Literal["text"]
    cache_control: NotRequired[ChatMessageContentItemCacheControlTypedDict]


class ChatMessageContentItemText(BaseModel):
    text: str

    TYPE: Annotated[
        Annotated[Literal["text"], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"

    cache_control: Optional[ChatMessageContentItemCacheControl] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from openrouter.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class NamedToolChoiceFunctionTypedDict(TypedDict):
    name: str


class NamedToolChoiceFunction(BaseModel):
    name: str


class NamedToolChoiceTypedDict(TypedDict):
    function: NamedToolChoiceFunctionTypedDict
    type: Literal["function"]


class NamedToolChoice(BaseModel):
    function: NamedToolChoiceFunction

    TYPE: Annotated[
        Annotated[Literal["function"], AfterValidator(validate_const("function"))],
        pydantic.Field(alias="type"),
    ] = "function"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responsesformatjsonobject import (
    ResponsesFormatJSONObject,
    ResponsesFormatJSONObjectTypedDict,
)
from .responsesformattext import ResponsesFormatText, ResponsesFormatTextTypedDict
from .responsesformattextjsonschemaconfig import (
    ResponsesFormatTextJSONSchemaConfig,
    ResponsesFormatTextJSONSchemaConfigTypedDict,
)
from openrouter.utils import get_discriminator
from pydantic import Discriminator, Tag
from typing import Union
from typing_extensions import Annotated, TypeAliasType


ResponseFormatTextConfigTypedDict = TypeAliasType(
    "ResponseFormatTextConfigTypedDict",
    Union[
        ResponsesFormatTextTypedDict,
        ResponsesFormatJSONObjectTypedDict,
        ResponsesFormatTextJSONSchemaConfigTypedDict,
    ],
)
r"""Text response format configuration"""


ResponseFormatTextConfig = Annotated[
    Union[
        Annotated[ResponsesFormatText, Tag("text")],
        Annotated[ResponsesFormatJSONObject, Tag("json_object")],
        Annotated[ResponsesFormatTextJSONSchemaConfig, Tag("json_schema")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]
r"""Text response format configuration"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .websearchstatus import WebSearchStatus
from openrouter.types import BaseModel
from openrouter.utils import validate_open_enum
from pydantic.functional_validators import PlainValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


ResponsesWebSearchCallOutputType = Literal["web_search_call",]


class ResponsesWebSearchCallOutputTypedDict(TypedDict):
    type: ResponsesWebSearchCallOutputType
    id: str
    status: WebSearchStatus


class ResponsesWebSearchCallOutput(BaseModel):
    type: ResponsesWebSearchCallOutputType

    id: str

    status: Annotated[WebSearchStatus, PlainValidator(validate_open_enum(False))]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseInputVideoType = Literal["input_video",]


class ResponseInputVideoTypedDict(TypedDict):
    r"""Video input content item"""

    type: ResponseInputVideoType
    video_url: str
    r"""A base64 data URL or remote URL that resolves to a video file"""


class ResponseInputVideo(BaseModel):
    r"""Video input content item"""

    type: ResponseInputVideoType

    video_url: str
    r"""A base64 data URL or remote URL that resolves to a video file"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import UnrecognizedStr
from typing import Literal, Union


ResponsesSearchContextSize = Union[
    Literal[
        "low",
        "medium",
        "high",
    ],
    UnrecognizedStr,
]
r"""Size of the search context for web search tools"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseformatjsonschema import (
    ResponseFormatJSONSchema,
    ResponseFormatJSONSchemaTypedDict,
)
from .responseformattextgrammar import (
    ResponseFormatTextGrammar,
    ResponseFormatTextGrammarTypedDict,
)
from openrouter.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from openrouter.utils import get_discriminator, validate_const
import pydantic
from pydantic import Discriminator, Tag, model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


PromptTypedDict = TypeAliasType(
    "PromptTypedDict", Union[str, List[str], List[float], List[List[float]]]
)


Prompt = TypeAliasType("Prompt", Union[str, List[str], List[float], List[List[float]]])


CompletionCreateParamsStopTypedDict = TypeAliasType(
    "CompletionCreateParamsStopTypedDict", Union[str, List[str]]
)


CompletionCreateParamsStop = TypeAliasType(
    "CompletionCreateParamsStop", Union[str, List[str]]
)


class StreamOptionsTypedDict(TypedDict):
    include_usage: NotRequired[Nullable[bool]]


class StreamOptions(BaseModel):
    include_usage: OptionalNullable[bool] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["include_usage"]
        nullable_fields = ["include_usage"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class CompletionCreateParamsResponseFormatPythonTypedDict(TypedDict):
    type: Literal["python"]


class CompletionCreateParamsResponseFormatPython(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["python"], AfterValidator(validate_const("python"))],
        pydantic.Field(alias="type"),
    ] = "python"


class CompletionCreateParamsResponseFormatJSONObjectTypedDict(TypedDict):
    type: Literal["json_object"]


class CompletionCreateParamsResponseFormatJSONObject(BaseModel):
    TYPE: Annotated[
        Annotated[
            Literal["json_object"], AfterValidator(validate_const("json_object"))
        ],
        pydantic.Field(alias="type"),
    ] = "json_object"


class CompletionCreateParamsResponseFormatTextTypedDict(TypedDict):
    type: Literal["text"]


class CompletionCreateParamsResponseFormatText(BaseModel):
    TYPE: Annotated[
        Annotated[Literal["text"], AfterValidator(validate_const("text"))],
        pydantic.Field(alias="type"),
    ] = "text"


CompletionCreateParamsResponseFormatUnionTypedDict = TypeAliasType(
    "CompletionCreateParamsResponseFormatUnionTypedDict",
    Union[
        CompletionCreateParamsResponseFormatTextTypedDict,
        CompletionCreateParamsResponseFormatJSONObjectTypedDict,
        CompletionCreateParamsResponseFormatPythonTypedDict,
        ResponseFormatJSONSchemaTypedDict,
        ResponseFormatTextGrammarTypedDict,
    ],
)


CompletionCreateParamsResponseFormatUnion = Annotated[
    Union[
        Annotated[CompletionCreateParamsResponseFormatText, Tag("text")],
        Annotated[CompletionCreateParamsResponseFormatJSONObject, Tag("json_object")],
        Annotated[ResponseFormatJSONSchema, Tag("json_schema")],
        Annotated[ResponseFormatTextGrammar, Tag("grammar")],
        Annotated[CompletionCreateParamsResponseFormatPython, Tag("python")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]


class CompletionCreateParamsTypedDict(TypedDict):
    prompt: PromptTypedDict
    model: NotRequired[str]
    models: NotRequired[List[str]]
    best_of: NotRequired[Nullable[int]]
    echo: NotRequired[Nullable[bool]]
    frequency_penalty: NotRequired[Nullable[float]]
    logit_bias: NotRequired[Nullable[Dict[str, float]]]
    logprobs: NotRequired[Nullable[int]]
    max_tokens: NotRequired[Nullable[int]]
    n: NotRequired[Nullable[int]]
    presence_penalty: NotRequired[Nullable[float]]
    seed: NotRequired[Nullable[int]]
    stop: NotRequired[Nullable[CompletionCreateParamsStopTypedDict]]
    stream: NotRequired[bool]
    stream_options: NotRequired[Nullable[StreamOptionsTypedDict]]
    suffix: NotRequired[Nullable[str]]
    temperature: NotRequired[Nullable[float]]
    top_p: NotRequired[Nullable[float]]
    user: NotRequired[str]
    metadata: NotRequired[Nullable[Dict[str, str]]]
    response_format: NotRequired[
        Nullable[CompletionCreateParamsResponseFormatUnionTypedDict]
    ]


class CompletionCreateParams(BaseModel):
    prompt: Prompt

    model: Optional[str] = None

    models: Optional[List[str]] = None

    best_of: OptionalNullable[int] = UNSET

    echo: OptionalNullable[bool] = UNSET

    frequency_penalty: OptionalNullable[float] = UNSET

    logit_bias: OptionalNullable[Dict[str, float]] = UNSET

    logprobs: OptionalNullable[int] = UNSET

    max_tokens: OptionalNullable[int] = UNSET

    n: OptionalNullable[int] = UNSET

    presence_penalty: OptionalNullable[float] = UNSET

    seed: OptionalNullable[int] = UNSET

    stop: OptionalNullable[CompletionCreateParamsStop] = UNSET

    stream: Optional[bool] = False

    stream_options: OptionalNullable[StreamOptions] = UNSET

    suffix: OptionalNullable[str] = UNSET

    temperature: OptionalNullable[float] = UNSET

    top_p: OptionalNullable[float] = UNSET

    user: Optional[str] = None

    metadata: OptionalNullable[Dict[str, str]] = UNSET

    response_format: OptionalNullable[CompletionCreateParamsResponseFormatUnion] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "model",
            "models",
            "best_of",
            "echo",
            "frequency_penalty",
            "logit_bias",
            "logprobs",
            "max_tokens",
            "n",
            "presence_penalty",
            "seed",
            "stop",
            "stream",
            "stream_options",
            "suffix",
            "temperature",
            "top_p",
            "user",
            "metadata",
            "response_format",
        ]
        nullable_fields = [
            "best_of",
            "echo",
            "frequency_penalty",
            "logit_bias",
            "logprobs",
            "max_tokens",
            "n",
            "presence_penalty",
            "seed",
            "stop",
            "stream_options",
            "suffix",
            "temperature",
            "top_p",
            "metadata",
            "response_format",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing import Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


ResponsesOutputItemFunctionCallType = Literal["function_call",]


ResponsesOutputItemFunctionCallStatusInProgress = Literal["in_progress",]


ResponsesOutputItemFunctionCallStatusIncomplete = Literal["incomplete",]


ResponsesOutputItemFunctionCallStatusCompleted = Literal["completed",]


ResponsesOutputItemFunctionCallStatusUnionTypedDict = TypeAliasType(
    "ResponsesOutputItemFunctionCallStatusUnionTypedDict",
    Union[
        ResponsesOutputItemFunctionCallStatusCompleted,
        ResponsesOutputItemFunctionCallStatusIncomplete,
        ResponsesOutputItemFunctionCallStatusInProgress,
    ],
)


ResponsesOutputItemFunctionCallStatusUnion = TypeAliasType(
    "ResponsesOutputItemFunctionCallStatusUnion",
    Union[
        ResponsesOutputItemFunctionCallStatusCompleted,
        ResponsesOutputItemFunctionCallStatusIncomplete,
        ResponsesOutputItemFunctionCallStatusInProgress,
    ],
)


class ResponsesOutputItemFunctionCallTypedDict(TypedDict):
    type: ResponsesOutputItemFunctionCallType
    name: str
    arguments: str
    call_id: str
    id: NotRequired[str]
    status: NotRequired[ResponsesOutputItemFunctionCallStatusUnionTypedDict]


class ResponsesOutputItemFunctionCall(BaseModel):
    type: ResponsesOutputItemFunctionCallType

    name: str

    arguments: str

    call_id: str

    id: Optional[str] = None

    status: Optional[ResponsesOutputItemFunctionCallStatusUnion] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from openrouter.types import BaseModel
from typing_extensions import TypedDict


class GetCreditsDataTypedDict(TypedDict):
    total_credits: float
    r"""Total credits purchased"""
    total_usage: float
    r"""Total credits used"""


class GetCreditsData(BaseModel):
    total_credits: float
    r"""Total credits purchased"""

    total_usage: float
    r"""Total credits used"""


class GetCreditsResponseTypedDict(TypedDict):
    r"""Total credits purchased and used"""

    data: GetCreditsDataTypedDict


class GetCreditsResponse(BaseModel):
    r"""Total credits purchased and used"""

    data: GetCreditsData
